pm4py.algo.discovery.minimum\_self\_distance package
====================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.minimum_self_distance.variants

Submodules
----------

pm4py.algo.discovery.minimum\_self\_distance.algorithm module
-------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.minimum_self_distance.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.minimum\_self\_distance.utils module
---------------------------------------------------------

.. automodule:: pm4py.algo.discovery.minimum_self_distance.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.minimum_self_distance
   :members:
   :undoc-members:
   :show-inheritance:
